@@ -8,7 +8,7 @@ use File::Spec;
 use Hash::Util qw(lock_hash);
 use Exporter 'import';
 use Log::Log4perl 1.54 qw(get_logger :levels);
-use Carp;
+use Carp qw(confess);
 
 use App::SpamcupNG::HTMLParse (
     'find_next_id',       'find_errors',
@@ -18,6 +18,7 @@ use App::SpamcupNG::HTMLParse (
 );
 use App::SpamcupNG::Summary;
 use App::SpamcupNG::UserAgent;
+use App::SpamcupNG::Summary::Recorder;
 
 use constant TARGET_HTML_FORM => 'sendreport';
 
@@ -30,6 +31,7 @@ our %OPTIONS_MAP = (
     'alt_code'   => 'c',
     'alt_user'   => 'l',
     'verbosity'  => 'V',
+    'database'   => { enabled => 0 }
 );
 
 my %regexes = (
@@ -39,7 +41,7 @@ my %regexes = (
 
 lock_hash(%OPTIONS_MAP);
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 =head1 NAME
 
@@ -80,16 +82,23 @@ configuration file.
 sub read_config {
     my ( $cfg, $cmd_opts ) = @_;
     my $data = LoadFile($cfg);
+    confess 'second parameter must be a hash reference'
+        unless ( ref($cmd_opts) eq 'HASH' );
 
     # sanity checking
     for my $opt ( keys( %{ $data->{ExecutionOptions} } ) ) {
-        die
-"$opt is not a valid option for configuration files. Check the documentation."
+        confess
+"'$opt' is not a valid option for configuration files. Check the documentation."
             unless ( exists( $OPTIONS_MAP{$opt} ) );
     }
 
     for my $opt ( keys(%OPTIONS_MAP) ) {
 
+        if ( $opt eq 'database' ) {
+            $cmd_opts->{$opt} = $data->{ExecutionOptions}->{$opt};
+            next;
+        }
+
         if ( $opt eq 'verbosity' ) {
             $cmd_opts->{'V'} = $data->{ExecutionOptions}->{$opt};
             next;
@@ -184,9 +193,9 @@ L<Log::Log4perl> for more details about the levels.
 
 sub config_logger {
     my ( $level, $log_file ) = @_;
-    croak "Must receive a string for the level parameter"
+    confess "Must receive a string for the level parameter"
         unless ( ( defined($level) ) and ( $level ne '' ) );
-    croak "Must receive a string for the log file parameter"
+    confess "Must receive a string for the log file parameter"
         unless ( ( defined($log_file) ) and ( $log_file ne '' ) );
 
 # :TODO:21/01/2018 12:07:01:ARFREITAS: Do we need to import :levels from Log::Log4perl at all?
@@ -197,7 +206,7 @@ sub config_logger {
         ERROR => $ERROR,
         FATAL => $FATAL
     );
-    croak "The value '$level' is not a valid value for level"
+    confess "The value '$level' is not a valid value for level"
         unless ( exists( $levels{$level} ) );
 
     my $conf;
@@ -439,6 +448,7 @@ sub main_loop {
     my $spam_header_info = find_header_info($response_ref);
     $summary->set_mailer( $spam_header_info->{mailer} );
     $summary->set_content_type( $spam_header_info->{content_type} );
+    $summary->set_charset( $spam_header_info->{charset} );
 
     if ( $logger->is_info ) {
         $logger->info( 'X-Mailer: ' . $summary->to_text('mailer') );
@@ -657,6 +667,16 @@ EOM
     $logger->debug( 'SPAM report summary: ' . $summary->as_text )
         if ( $logger->is_debug );
 
+    if ( $opts_ref->{database}->{enabled} ) {
+        $logger->info( 'Persisting summary to SQLite database at '
+                . $opts_ref->{database}->{path} )
+            if ( $logger->is_info );
+        my $recorder = App::SpamcupNG::Summary::Recorder->new(
+            $opts_ref->{database}->{path} );
+        $recorder->init;
+        $recorder->save($summary);
+    }
+
     return 1;
 
     # END OF THE LOOP
